@@ -235,7 +235,9 @@ def step_the_command_returncode_is_nonzero(context):
 @then("it should pass")
 def step_it_should_pass(context):
     assert_that(
-        context.command_result.returncode, equal_to(0), context.command_result.output
+        context.command_result.returncode,
+        equal_to(0),
+        "Expected to pass but failed with content:\n" + context.command_result.output,
     )
 
 
@@ -244,7 +246,7 @@ def step_it_should_fail(context):
     assert_that(
         context.command_result.returncode,
         is_not(equal_to(0)),
-        context.command_result.output,
+        "Expected to fail but passed with content:\n" + context.command_result.output,
     )
 
 
